add_overscan_header — MSUMastro toolbox 0.1 documentation

# add_overscan_header

`msumastro.header_processing.patchers.` `add_overscan_header`(header, history=True)

  Add overscan information to a FITS header.

  Parameters: | header : astropy.io.fits.Header Header object to which overscan is to be added. history : bool, optional If True, add history of keyword modification to header.
  Returns: | list of str List of the keywords added to the header by this function.